"""
RxNorm_get_drug_names

Get RXCUI (RxNorm Concept Unique Identifier) and all associated names (generic names, brand names...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def RxNorm_get_drug_names(
    drug_name: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get RXCUI (RxNorm Concept Unique Identifier) and all associated names (generic names, brand names...

    Parameters
    ----------
    drug_name : str
        The name of the drug to search for (e.g., 'ibuprofen', 'aspirin', 'acetaminop...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {k: v for k, v in {"drug_name": drug_name}.items() if v is not None}
    return get_shared_client().run_one_function(
        {
            "name": "RxNorm_get_drug_names",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["RxNorm_get_drug_names"]
